@@ -37,7 +37,8 @@ log = logging.getLogger(__name__)
 
 class SmartDriver(SeleniumDriverCore):
     def __init__(self, driver, api_key=None, initialization_dict={}):
-        self.version = 'selenium-0.1.14'
+        self.version = 'selenium-0.1.23'
+        self.automation_name = driver.capabilities.get('browserName', '')
         SeleniumDriverCore.__init__(self, driver, api_key, initialization_dict)
         window_size = self.driver.get_window_size()
         self.window_size = window_size
@@ -50,6 +51,7 @@ class SmartDriver(SeleniumDriverCore):
         self_attrs = dir(self)
         # Disable warnings
         requests.packages.urllib3.disable_warnings()
+
         warnings.filterwarnings("ignore", category=DeprecationWarning)
 
     def _get_screenshot(self):
@@ -98,7 +100,7 @@ class SmartDriver(SeleniumDriverCore):
                 return element, self.last_test_case_screenshot_uuid, msg
             else:
                 event_id = str(uuid.uuid4())
-                label_url = f'{self.url}/testcase/label?test_case_name={urllib.parse.quote(self.test_case_uuid)}&event_id={event_id}'
+                label_url = f'{self.url}/testcase/label?test_case_name={urllib.parse.quote(self.test_case_uuid)}&event_id={event_id}&api_key={self.api_key}'
                 log.info('Waiting for bounding box of element {} to be drawn in the UI: \n\t{}'.format(element_name,
                                                                                                        label_url))
                 webbrowser.open(label_url)
